@@ -10,9 +10,10 @@ from pandas import DataFrame, Series
 import lunchbox.tools as lbt
 import networkx
 import numpy as np
+import pandas as pd
 
 from rolling_pin.radon_etl import RadonETL
-import rolling_pin.tools as tools
+import rolling_pin.tools as rpt
 # ------------------------------------------------------------------------------
 
 '''
@@ -109,7 +110,7 @@ class RepoETL():
             DataFrame: DataFrame of file information.
         '''
         root = Path(root).as_posix()
-        files = tools.list_all_files(root)  # type: Union[Iterator, List]
+        files = rpt.list_all_files(root)  # type: Union[Iterator, List]
         if include_regex != '':
             if not include_regex.endswith(r'\.py$'):
                 msg = f"Invalid include_regex: '{include_regex}'. "
@@ -143,7 +144,7 @@ class RepoETL():
             .apply(lambda x: re.sub('/', '.', x))
 
         data['subpackages'] = data.node_name\
-            .apply(lambda x: tools.get_parent_fields(x, '.')).apply(lbt.get_ordered_unique)
+            .apply(lambda x: rpt.get_parent_fields(x, '.')).apply(lbt.get_ordered_unique)
         data.subpackages = data.subpackages\
             .apply(lambda x: list(filter(lambda y: y != '', x)))
 
@@ -165,11 +166,11 @@ class RepoETL():
                 lambda x: dict(
                     node_name=x,
                     node_type='subpackage',
-                    dependencies=tools.get_parent_fields(x, '.'),
-                    subpackages=tools.get_parent_fields(x, '.'),
+                    dependencies=rpt.get_parent_fields(x, '.'),
+                    subpackages=rpt.get_parent_fields(x, '.'),
                 )).tolist()
         pkgs = DataFrame(pkgs)
-        data = data.append(pkgs, ignore_index=True, sort=True)
+        data = pd.concat([data, pkgs], ignore_index=True, sort=True)
 
         # add library dependencies as nodes
         libs = set(chain(*data.dependencies.tolist()))  # type: Any
@@ -184,7 +185,7 @@ class RepoETL():
                     subpackages=[],
                 )).tolist()
         libs = DataFrame(libs)
-        data = data.append(libs, ignore_index=True, sort=True)
+        data = pd.concat([data, libs], ignore_index=True, sort=True)
 
         data.drop_duplicates('node_name', inplace=True)
         data.reset_index(drop=True, inplace=True)
@@ -401,7 +402,7 @@ class RepoETL():
 
         # set color scheme of graph
         if color_scheme is None:
-            color_scheme = tools.COLOR_SCHEME
+            color_scheme = rpt.COLOR_SCHEME
 
         # create dot graph
         graph = self.to_networkx_graph()
@@ -503,13 +504,13 @@ class RepoETL():
             IPython.display.HTML: HTML object for inline display.
         '''
         if color_scheme is None:
-            color_scheme = tools.COLOR_SCHEME
+            color_scheme = rpt.COLOR_SCHEME
 
         dot = self.to_dot_graph(
             orthogonal_edges=orthogonal_edges,
             color_scheme=color_scheme,
         )
-        return tools.dot_to_html(dot, layout=layout, as_png=as_png)
+        return rpt.dot_to_html(dot, layout=layout, as_png=as_png)
 
     def write(
         self,
@@ -556,7 +557,7 @@ class RepoETL():
             return self
 
         if color_scheme is None:
-            color_scheme = tools.COLOR_SCHEME
+            color_scheme = rpt.COLOR_SCHEME
 
         graph = self.to_dot_graph(
             orient=orient,
@@ -564,7 +565,7 @@ class RepoETL():
             color_scheme=color_scheme,
         )
         try:
-            tools.write_dot_graph(graph, fullpath, layout=layout,)
+            rpt.write_dot_graph(graph, fullpath, layout=layout,)
         except ValueError:
             msg = f'Invalid extension found: {ext}. '
             msg += 'Valid extensions include: svg, dot, png, json.'
